#[non_exhaustive]pub enum PartitionAggregationError {
EmptyPlan,
PlanTooLarge {
max: usize,
},
DuplicateKey,
Incomplete {
status: BatchStatus,
},
CountExhausted,
}Expand description
A deterministic partition plan could not be aggregated safely.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyPlan
No durable child result was supplied.
PlanTooLarge
The supplied plan exceeded the accepted M4 partition bound.
DuplicateKey
More than one child used the same byte-exact key.
Incomplete
At least one child did not have a durable runtime-terminal result.
Fields

status: BatchStatusThe unusable durable status.
CountExhausted
At least one aggregate counter exceeded u64.