pub struct RecoveryMarkers(/* private fields */);Expand description
Closed boolean recovery markers retained as one bounded bit set.
Implementations
Sourceimpl RecoveryMarkers
impl RecoveryMarkers
Sourcepub const fn with_unknown_commit(self, value: bool) -> Self
pub const fn with_unknown_commit(self, value: bool) -> Self
Records whether the last durable marker is an unknown commit.
Sourcepub const fn with_completed_partition(self, value: bool) -> Self
pub const fn with_completed_partition(self, value: bool) -> Self
Records whether completed partition evidence exists.
Sourcepub const fn with_committed_flow_decision(self, value: bool) -> Self
pub const fn with_committed_flow_decision(self, value: bool) -> Self
Records whether a committed flow decision exists.
Sourcepub const fn with_ambiguous_external_effect(self, value: bool) -> Self
pub const fn with_ambiguous_external_effect(self, value: bool) -> Self
Records whether the definition declares an ambiguous external effect.