pub struct RetentionRecord { /* private fields */ }Expand description
One append-only retention audit record.
Implementations
Sourceimpl RetentionRecord
impl RetentionRecord
Sourcepub fn from_parts(id: RetentionActionId, draft: RetentionRecordDraft) -> Self
pub fn from_parts(id: RetentionActionId, draft: RetentionRecordDraft) -> Self
Rebuilds a record read from a durable adapter.
Sourcepub const fn id(&self) -> RetentionActionId
pub const fn id(&self) -> RetentionActionId
Returns the opaque record identifier.
Sourcepub const fn action(&self) -> RetentionAction
pub const fn action(&self) -> RetentionAction
Returns the audited action.
Sourcepub const fn operation_id(&self) -> &OperationId
pub const fn operation_id(&self) -> &OperationId
Borrows the idempotency key.
Sourcepub const fn reason(&self) -> &ReasonCode
pub const fn reason(&self) -> &ReasonCode
Borrows the closed-set reason code.
Sourcepub const fn job_instance_id(&self) -> Option<JobInstanceId>
pub const fn job_instance_id(&self) -> Option<JobInstanceId>
Returns the held instance, when the action targeted one.
Sourcepub const fn plan_digest(&self) -> Option<&[u8; 32]>
pub const fn plan_digest(&self) -> Option<&[u8; 32]>
Returns the applied plan digest, when the action was a purge.
Sourcepub const fn counts(&self) -> PurgeCounts
pub const fn counts(&self) -> PurgeCounts
Returns the per-table deleted counts.
Sourcepub const fn batch_bound(&self) -> Option<PurgeBatchBound>
pub const fn batch_bound(&self) -> Option<PurgeBatchBound>
Returns the batch bound, when the action was a purge.
Sourcepub const fn outcome(&self) -> RetentionOutcome
pub const fn outcome(&self) -> RetentionOutcome
Returns the recorded outcome class.
Sourcepub const fn applied_at(&self) -> SystemTime
pub const fn applied_at(&self) -> SystemTime
Returns the facade-clock instant of the audited action.