pub struct SequentialIdGenerator { /* private fields */ }Expand description
A thread-safe nonzero identifier sequence suitable for local execution.
The sequence is deterministic for a given call order. A single sequence is shared by all identifier kinds so generated values cannot collide when records are inspected together.
Implementations
Sourceimpl SequentialIdGenerator
impl SequentialIdGenerator
Sourcepub const fn new(first: NonZeroU64) -> Self
pub const fn new(first: NonZeroU64) -> Self
Constructs a sequence whose first returned value is first.