StepExecutionProjection

Struct StepExecutionProjection 

pub struct StepExecutionProjection { /* private fields */ }
A redacted step execution projection.

Implementations

Source

impl StepExecutionProjection

pub const fn id(&self) -> StepExecutionId

Returns the opaque step-execution identifier.

pub const fn job_execution_id(&self) -> JobExecutionId

Returns the owning job execution.

pub const fn step_name(&self) -> &StepName

Borrows the durable step name.

pub const fn node_id(&self) -> Option<&NodeId>

Borrows the stable logical node identifier, when the adapter records one.

pub const fn status(&self) -> BatchStatus

Returns the framework status.

pub const fn exit_status(&self) -> &ExitStatus

Borrows the operator-facing exit status.

pub const fn counts(&self) -> ExecutionCounts

Returns the durable counters.

pub const fn version(&self) -> ExecutionVersion

Returns the observed optimistic version.

pub const fn timestamps(&self) -> ExecutionTimestamps

Returns the lifecycle timestamps.

pub const fn failure(&self) -> Option<FailureSummary>

Returns the framework failure category and opaque failure identifier.

pub const fn checkpoint(&self) -> Option<&StateEnvelopeDescriptor>

Borrows the checkpoint envelope description.

pub const fn context(&self) -> Option<&StateEnvelopeDescriptor>

Borrows the step-context envelope description.