pub struct StepPartition { /* private fields */ }Expand description
A durable partition plan row and its latest result snapshot.
Implementations
Sourceimpl StepPartition
impl StepPartition
Sourcepub const fn id(&self) -> StepPartitionId
pub const fn id(&self) -> StepPartitionId
Returns the durable partition-row identifier.
Sourcepub const fn step_execution_id(&self) -> StepExecutionId
pub const fn step_execution_id(&self) -> StepExecutionId
Returns the parent partitioned step execution.
Sourcepub const fn worker_step_execution_id(&self) -> Option<StepExecutionId>
pub const fn worker_step_execution_id(&self) -> Option<StepExecutionId>
Returns the assigned worker attempt, when one has started.
Sourcepub const fn key(&self) -> &PartitionKey
pub const fn key(&self) -> &PartitionKey
Borrows the stable partition key.
Sourcepub const fn status(&self) -> BatchStatus
pub const fn status(&self) -> BatchStatus
Returns the current framework status.
Sourcepub const fn exit_status(&self) -> &ExitStatus
pub const fn exit_status(&self) -> &ExitStatus
Borrows the latest stable exit status.
Sourcepub const fn counts(&self) -> ExecutionCounts
pub const fn counts(&self) -> ExecutionCounts
Returns the latest durable counters.
Sourcepub const fn context(&self) -> &ExecutionContext
pub const fn context(&self) -> &ExecutionContext
Borrows the redacted partition context.
Sourcepub const fn version(&self) -> ExecutionVersion
pub const fn version(&self) -> ExecutionVersion
Returns the optimistic-lock version.