pub struct JobInstanceProjection { /* private fields */ }Expand description
A redacted logical job instance projection.
Implementations
Sourceimpl JobInstanceProjection
impl JobInstanceProjection
Sourcepub const fn id(&self) -> JobInstanceId
pub const fn id(&self) -> JobInstanceId
Returns the opaque instance identifier.
Sourcepub const fn instance_key_digest(&self) -> &[u8; 32]
pub const fn instance_key_digest(&self) -> &[u8; 32]
Returns the canonical identifying-key digest.
Sourcepub fn instance_key_digest_hex(&self) -> String
pub fn instance_key_digest_hex(&self) -> String
Returns the hexadecimal identifying-key digest.
Sourcepub fn parameters(&self) -> &[ParameterDescriptor]
pub fn parameters(&self) -> &[ParameterDescriptor]
Borrows the redacted parameter descriptors.
Sourcepub const fn created_at(&self) -> Option<SystemTime>
pub const fn created_at(&self) -> Option<SystemTime>
Returns the durable creation instant when the adapter records one.
Sourcepub const fn hold(&self) -> Option<&RetentionHold>
pub const fn hold(&self) -> Option<&RetentionHold>
Borrows the active retention hold, when one is placed.