pub struct StepExecutionProjection { /* private fields */ }Expand description
A redacted step execution projection.
Implementations
Sourceimpl StepExecutionProjection
impl StepExecutionProjection
Sourcepub const fn id(&self) -> StepExecutionId
pub const fn id(&self) -> StepExecutionId
Returns the opaque step-execution identifier.
Sourcepub const fn job_execution_id(&self) -> JobExecutionId
pub const fn job_execution_id(&self) -> JobExecutionId
Returns the owning job execution.
Sourcepub const fn node_id(&self) -> Option<&NodeId>
pub const fn node_id(&self) -> Option<&NodeId>
Borrows the stable logical node identifier, when the adapter records one.
Sourcepub const fn status(&self) -> BatchStatus
pub const fn status(&self) -> BatchStatus
Returns the framework status.
Sourcepub const fn exit_status(&self) -> &ExitStatus
pub const fn exit_status(&self) -> &ExitStatus
Borrows the operator-facing exit status.
Sourcepub const fn counts(&self) -> ExecutionCounts
pub const fn counts(&self) -> ExecutionCounts
Returns the durable counters.
Sourcepub const fn version(&self) -> ExecutionVersion
pub const fn version(&self) -> ExecutionVersion
Returns the observed optimistic version.
Sourcepub const fn timestamps(&self) -> ExecutionTimestamps
pub const fn timestamps(&self) -> ExecutionTimestamps
Returns the lifecycle timestamps.
Sourcepub const fn failure(&self) -> Option<FailureSummary>
pub const fn failure(&self) -> Option<FailureSummary>
Returns the framework failure category and opaque failure identifier.
Sourcepub const fn checkpoint(&self) -> Option<&StateEnvelopeDescriptor>
pub const fn checkpoint(&self) -> Option<&StateEnvelopeDescriptor>
Borrows the checkpoint envelope description.
Sourcepub const fn context(&self) -> Option<&StateEnvelopeDescriptor>
pub const fn context(&self) -> Option<&StateEnvelopeDescriptor>
Borrows the step-context envelope description.